@@ -1,6 +1,6 @@
 package DBIx::Class::Schema::AuditLog::Structure::Field;
 {
-  $DBIx::Class::Schema::AuditLog::Structure::Field::VERSION = '0.4.2';
+  $DBIx::Class::Schema::AuditLog::Structure::Field::VERSION = '0.5.0';
 }
 
 use base 'DBIx::Class::Schema::AuditLog::Structure::Base';
@@ -16,7 +16,7 @@ __PACKAGE__->add_columns(
         'is_auto_increment' => 1,
         'is_nullable'       => 0,
     },
-    'audited_table' => {
+    'audited_table_id' => {
         'data_type'   => 'integer',
         'is_nullable' => 0,
     },
@@ -32,13 +32,13 @@ __PACKAGE__->set_primary_key('id');
 __PACKAGE__->belongs_to(
     'AuditedTable',
     'DBIx::Class::Schema::AuditLog::Structure::AuditedTable',
-    { 'foreign.id' => 'self.audited_table' },
+    { 'foreign.id' => 'self.audited_table_id' },
 );
 
 __PACKAGE__->has_many(
     'Change',
     'DBIx::Class::Schema::AuditLog::Structure::Change',
-    { 'foreign.field' => 'self.id' },
+    { 'foreign.field_id' => 'self.id' },
 );
 
 1;
@@ -53,7 +53,7 @@ DBIx::Class::Schema::AuditLog::Structure::Field
 
 =head1 VERSION
 
-version 0.4.2
+version 0.5.0
 
 =head1 AUTHOR
 
